@@ -2015,7 +2015,7 @@ GVApi::callOut(AsyncTaskToken *token)
 }//GVApi::callOut
 
 void
-GVApi::onCallout(bool success, const QByteArray &response, QNetworkReply *,
+GVApi::onCallout(bool success, const QByteArray &response, QNetworkReply *reply,
                  void *ctx)
 {
     AsyncTaskToken *token = (AsyncTaskToken *)ctx;
@@ -2023,8 +2023,12 @@ GVApi::onCallout(bool success, const QByteArray &response, QNetworkReply *,
 
     do {
         if (!success) {
+            if (QNetworkReply::AuthenticationRequiredError != reply->error ()) {
+                token->status = ATTS_NW_ERROR;
+            } else {
+                token->status = ATTS_NOT_LOGGED_IN;
+            }
             Q_WARN("Failed to call out");
-            token->status = ATTS_NW_ERROR;
             break;
         }
         success = false;
@@ -2272,6 +2276,16 @@ GVApi::onSendSms(bool success, const QByteArray &response, QNetworkReply *,
             break;
         }
 
+        // SMS response also contains the new rnr_se token
+        strTemp = scriptEngine.evaluate ("o.rnr_xsrf_token;").toString ();
+        if (scriptEngine.hasUncaughtException ()) {
+            Q_WARN("Failed to parse rnr_se: ") << strReply;
+            Q_WARN("Error is: ") << strTemp;
+        }
+        if ((strTemp != "undefined") && (!strTemp.isEmpty())) {
+            rnr_se = strTemp;
+        }
+
         token->status = ATTS_SUCCESS;
         token->emitCompleted ();
         token = NULL;
